import { createSlice, PayloadAction } from '@reduxjs/toolkit';
import type { RootState } from './store';
import Graph, { MultiGraph } from 'graphology';
import { Attributes, SerializedGraph } from 'graphology-types';
import { QueryMultiGraph, QueryMultiGraphology as QueryGraphology } from '../../querybuilder/model/graphology/utils';

export type QueryBuilderSettings = {
  limit: number;
  depth: { min: number; max: number };
};

// Define the initial state using that type
export const initialState: {
  graphologySerialized: QueryMultiGraph;
  settings: QueryBuilderSettings;
} = {
  graphologySerialized: new QueryGraphology().export(),
  settings: {
    limit: 500,
    depth: { min: 0, max: 1 },
  },
  // schemaLayout: 'Graphology_noverlap',
};

export const querybuilderSlice = createSlice({
  name: 'querybuilder',
  // `createSlice` will infer the state type from the `initialState` argument
  initialState,
  reducers: {
    setQuerybuilderNodes: (state, action: PayloadAction<QueryMultiGraph>) => {
      // console.log('setQuerybuilderNodes', action.payload);
      // @ts-ignore
      state.graphologySerialized = QueryGraphology.from(action.payload).export();
      // state.graphologySerialized = action.payload;
    },
    // updateQBAttributeOperator: (state, action: PayloadAction<{ id: string; operator: string }>) => {
    //   const graph = QueryMultiGraphology.from(state.graphologySerialized);
    //   graph.setNodeAttribute(action.payload.id, 'operator', action.payload.operator);
    //   state.graphologySerialized = graph.export();
    // },
    // updateQBAttributeValue: (state, action: PayloadAction<{ id: string; value: string }>) => {
    //   const graph = QueryMultiGraphology.from(state.graphologySerialized);
    //   graph.setNodeAttribute(action.payload.id, 'value', action.payload.value);
    //   state.graphologySerialized = graph.export();
    // },
    clearQB: (state) => {
      state.graphologySerialized = new QueryGraphology().export();
    },
    setQuerybuilderSettings: (state, action: PayloadAction<QueryBuilderSettings>) => {
      state.settings = action.payload;
    },

    // addQuerybuilderNode: (
    //   state,
    //   action: PayloadAction<{ id: string; attributes: Attributes }>
    // ) => {
    //   const graph = MultiGraph.from(state.graphologySerialized);
    //   graph.addNode(action.payload.id, action.payload.attributes);
    //   state.graphologySerialized = graph.export();
    // },
    // setGraphLayout: (state, action: PayloadAction<AllLayoutAlgorithms>) => {
    //   state.schemaLayout = action.payload;
    // },
  },
});

export const { setQuerybuilderNodes, clearQB, setQuerybuilderSettings } = querybuilderSlice.actions;

export const queryBuilderSettingsState = (state: RootState) => state.querybuilder.settings;

/** Select the querybuilder nodes in serialized fromat */
export const selectQuerybuilderGraphology = (state: RootState): QueryGraphology => {
  // This is really weird but for some reason all the attributes appeared as read-only otherwise

  let ret = new QueryGraphology();
  ret.import(Graph.from(state.querybuilder.graphologySerialized).export());
  return ret;
};

/** Select the querybuilder nodes and convert it to a graphology object */
export const selectQuerybuilderGraph = (state: RootState): QueryMultiGraph => {
  // This is really weird but for some reason all the attributes appeared as read-only otherwise
  return state.querybuilder.graphologySerialized as QueryMultiGraph;
};

/** Select the querybuilder nodes and convert it to a graphology object */
export const selectQuerybuilderHash = (state: RootState): any => {
  const hashedNodes = state.querybuilder.graphologySerialized.nodes.map((n) => {
    let node = { ...n };
    if (n?.attributes) {
      let newAttributes = { ...n?.attributes };
      newAttributes.x = 0;
      newAttributes.y = 0;
      newAttributes.height = 0;
      newAttributes.width = 0;
      node.attributes = newAttributes;
    }
    return node;
  });

  return JSON.stringify({
    nodes: hashedNodes,
    edges: state.querybuilder.graphologySerialized.edges.map((n) => ({
      key: n.key,
      source: n.source,
      target: n.target,
    })),
  });
};

// /**
//  * selects the SchemaLayout enum
//  * @param {GraphLayout} state
//  * @returns {GraphLayout} enum of type GraphLayout
//  */
// export const selectSchemaLayout = (state: RootState) =>
//   state.schema.schemaLayout;

export default querybuilderSlice.reducer;
